Package: RSSL
Version: 0.9.8
Title: Implementations of Semi-Supervised Learning Approaches for
        Classification
Authors@R: c(person("Jesse", "Krijthe", role = c("aut", "cre"),
    email = "jkrijthe@gmail.com"))
Depends: R(>= 2.10.0)
Imports: methods, Rcpp, MASS, kernlab, quadprog, Matrix, dplyr, tidyr,
        ggplot2, reshape2, scales, cluster
LinkingTo: Rcpp, RcppArmadillo
Suggests: testthat, rmarkdown, SparseM, numDeriv, LiblineaR, covr
Description: A collection of implementations of semi-supervised classifiers
    and methods to evaluate their performance. The package includes implementations
    of, among others, Implicitly Constrained Learning, Moment Constrained Learning,
    the Transductive SVM, Manifold regularization, Maximum Contrastive Pessimistic
    Likelihood estimation, S4VM and WellSVM.
License: GPL (>= 2)
URL: https://github.com/jkrijthe/RSSL
BugReports: https://github.com/jkrijthe/RSSL/issues
Collate: 'Generics.R' 'Classifier.R' 'CrossValidation.R'
        'LeastSquaresClassifier.R' 'EMLeastSquaresClassifier.R'
        'NormalBasedClassifier.R' 'LinearDiscriminantClassifier.R'
        'EMLinearDiscriminantClassifier.R' 'NearestMeanClassifier.R'
        'EMNearestMeanClassifier.R' 'LogisticRegression.R'
        'EntropyRegularizedLogisticRegression.R' 'Evaluate.R'
        'GRFClassifier.R' 'GenerateSSLData.R' 'HelperFunctions.R'
        'ICLeastSquaresClassifier.R' 'ICLinearDiscriminantClassifier.R'
        'KernelLeastSquaresClassifier.R'
        'KernelICLeastSquaresClassifier.R'
        'LaplacianKernelLeastSquaresClassifier.R' 'LaplacianSVM.R'
        'LearningCurve.R' 'LinearSVM.R' 'LogisticLossClassifier.R'
        'MCLinearDiscriminantClassifier.R' 'MCNearestMeanClassifier.R'
        'MCPLDA.R' 'MajorityClassClassifier.R' 'Measures.R'
        'Plotting.R' 'QuadraticDiscriminantClassifier.R'
        'RSSL-package.R' 'RcppExports.R' 'S4VM.R' 'SVM.R'
        'SelfLearning.R' 'TSVM.R' 'USMLeastSquaresClassifier.R'
        'WellSVM.R' 'scaleMatrix.R' 'svmd.R' 'svmlin.R'
        'testdata-data.R'
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: yes
Packaged: 2025-10-21 21:28:51 UTC; jkrijthe
Author: Jesse Krijthe [aut, cre]
Maintainer: Jesse Krijthe <jkrijthe@gmail.com>
Repository: CRAN
Date/Publication: 2025-10-21 21:50:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 21:17:58 UTC; unix
Archs: RSSL.so.dSYM
