# Generated by roxygen2: do not edit by hand

S3method(CrossValidationSSL,list)
S3method(CrossValidationSSL,matrix)
S3method(LearningCurveSSL,list)
S3method(LearningCurveSSL,matrix)
S3method(c,CrossValidation)
S3method(plot,CrossValidation)
S3method(plot,LearningCurve)
S3method(print,CrossValidation)
S3method(print,LearningCurve)
S3method(summary,CrossValidation)
S3method(svmd,default)
S3method(svmd,formula)
export(BaseClassifier)
export(CrossValidationSSL)
export(EMLeastSquaresClassifier)
export(EMLinearDiscriminantClassifier)
export(EMNearestMeanClassifier)
export(EntropyRegularizedLogisticRegression)
export(GRFClassifier)
export(ICLeastSquaresClassifier)
export(ICLinearDiscriminantClassifier)
export(KernelICLeastSquaresClassifier)
export(KernelLeastSquaresClassifier)
export(LaplacianKernelLeastSquaresClassifier)
export(LaplacianSVM)
export(LearningCurveSSL)
export(LeastSquaresClassifier)
export(LinearDiscriminantClassifier)
export(LinearSVM)
export(LinearTSVM)
export(LogisticLossClassifier)
export(LogisticRegression)
export(LogisticRegressionFast)
export(MCLinearDiscriminantClassifier)
export(MCNearestMeanClassifier)
export(MCPLDA)
export(MajorityClassClassifier)
export(NearestMeanClassifier)
export(PreProcessing)
export(PreProcessingPredict)
export(QuadraticDiscriminantClassifier)
export(S4VM)
export(SSLDataFrameToMatrices)
export(SVM)
export(SelfLearning)
export(TSVM)
export(USMLeastSquaresClassifier)
export(WellSVM)
export(add_missinglabels_mar)
export(clapply)
export(cov_ml)
export(decisionvalues)
export(df_to_matrices)
export(generate2ClassGaussian)
export(generateABA)
export(generateCrescentMoon)
export(generateFourClusters)
export(generateParallelPlanes)
export(generateSlicedCookie)
export(generateSpirals)
export(generateTwoCircles)
export(geom_classifier)
export(geom_linearclassifier)
export(line_coefficients)
export(logsumexp)
export(loss)
export(losslogsum)
export(losspart)
export(measure_accuracy)
export(measure_error)
export(measure_losslab)
export(measure_losstest)
export(measure_losstrain)
export(missing_labels)
export(posterior)
export(responsibilities)
export(sample_k_per_level)
export(scaleMatrix)
export(solve_svm)
export(split_dataset_ssl)
export(split_random)
export(stat_classifier)
export(stderror)
export(svmlin)
export(true_labels)
exportMethods(loss)
exportMethods(predict)
exportMethods(show)
import(Matrix)
import(dplyr)
import(ggplot2)
import(quadprog)
import(reshape2)
importFrom(MASS,ginv)
importFrom(MASS,mvrnorm)
importFrom(Rcpp,sourceCpp)
importFrom(cluster,pam)
importFrom(kernlab,as.kernelMatrix)
importFrom(kernlab,kernelMatrix)
importFrom(kernlab,rbfdot)
importFrom(kernlab,vanilladot)
importFrom(methods,.hasSlot)
importFrom(methods,as)
importFrom(methods,is)
importFrom(methods,new)
importFrom(stats,binomial)
importFrom(stats,cov)
importFrom(stats,delete.response)
importFrom(stats,df)
importFrom(stats,dist)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,glm.fit)
importFrom(stats,median)
importFrom(stats,model.extract)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,na.fail)
importFrom(stats,na.omit)
importFrom(stats,napredict)
importFrom(stats,nlm)
importFrom(stats,optim)
importFrom(stats,princomp)
importFrom(stats,rbeta)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,terms)
importFrom(stats,var)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
useDynLib(RSSL, .registration = TRUE)
